@@ -21,8 +21,9 @@ class PromiscuousOperand:
 
 class AndList(list):
     """
-    A list of conditions to by applied to a query expression by logical conjunction: the conditions are AND-ed.
-    All other collections (lists, sets, other entity sets, etc) are applied by logical disjunction (OR).
+    A list of conditions to by applied to a query expression by logical conjunction: the
+    conditions are AND-ed. All other collections (lists, sets, other entity sets, etc) are
+    applied by logical disjunction (OR).
 
     Example:
     expr2 = expr & dj.AndList((cond1, cond2, cond3))
@@ -49,6 +50,7 @@ def assert_join_compatibility(expr1, expr2):
     the matching attributes in the two expressions must be in the primary key of one or the
     other expression.
     Raises an exception if not compatible.
+
     :param expr1: A QueryExpression object
     :param expr2: A QueryExpression object
     """
@@ -56,7 +58,8 @@ def assert_join_compatibility(expr1, expr2):
 
     for rel in (expr1, expr2):
         if not isinstance(rel, (U, QueryExpression)):
-            raise DataJointError('Object %r is not a QueryExpression and cannot be joined.' % rel)
+            raise DataJointError(
+                'Object %r is not a QueryExpression and cannot be joined.' % rel)
     if not isinstance(expr1, U) and not isinstance(expr2, U):  # dj.U is always compatible
         try:
             raise DataJointError(
@@ -70,9 +73,11 @@ def assert_join_compatibility(expr1, expr2):
 def make_condition(query_expression, condition, columns):
     """
     Translate the input condition into the equivalent SQL condition (a string)
+
     :param query_expression: a dj.QueryExpression object to apply condition
     :param condition: any valid restriction object.
-    :param columns: a set passed by reference to collect all column names used in the condition.
+    :param columns: a set passed by reference to collect all column names used in the
+        condition.
     :return: an SQL condition string or a boolean value.
     """
     from .expression import QueryExpression, Aggregation, U
@@ -102,12 +107,13 @@ def make_condition(query_expression, condition, columns):
     # restrict by string
     if isinstance(condition, str):
         columns.update(extract_column_names(condition))
-        return template % condition.strip().replace("%", "%%")  # escape % in strings, see issue #376
+        return template % condition.strip().replace("%", "%%")  # escape %, see issue #376
 
     # restrict by AndList
     if isinstance(condition, AndList):
         # omit all conditions that evaluate to True
-        items = [item for item in (make_condition(query_expression, cond, columns) for cond in condition)
+        items = [item for item in (make_condition(query_expression, cond, columns)
+                 for cond in condition)
                  if item is not True]
         if any(item is False for item in items):
             return negate  # if any item is False, the whole thing is False
@@ -123,18 +129,21 @@ def make_condition(query_expression, condition, columns):
     if isinstance(condition, bool):
         return negate != condition
 
-    # restrict by a mapping such as a dict -- convert to an AndList of string equality conditions
+    # restrict by a mapping/dict -- convert to an AndList of string equality conditions
     if isinstance(condition, collections.abc.Mapping):
         common_attributes = set(condition).intersection(query_expression.heading.names)
         if not common_attributes:
             return not negate  # no matching attributes -> evaluates to True
         columns.update(common_attributes)
         return template % ('(' + ') AND ('.join(
-            '`%s`=%s' % (k, prep_value(k, condition[k])) for k in common_attributes) + ')')
+            '`%s`%s' % (k, ' IS NULL' if condition[k] is None
+                        else f'={prep_value(k, condition[k])}')
+            for k in common_attributes) + ')')
 
     # restrict by a numpy record -- convert to an AndList of string equality conditions
     if isinstance(condition, numpy.void):
-        common_attributes = set(condition.dtype.fields).intersection(query_expression.heading.names)
+        common_attributes = set(condition.dtype.fields).intersection(
+            query_expression.heading.names)
         if not common_attributes:
             return not negate   # no matching attributes -> evaluate to True
         columns.update(common_attributes)
@@ -154,7 +163,8 @@ def make_condition(query_expression, condition, columns):
     if isinstance(condition, QueryExpression):
         if check_compatibility:
             assert_join_compatibility(query_expression, condition)
-        common_attributes = [q for q in condition.heading.names if q in query_expression.heading.names]
+        common_attributes = [q for q in condition.heading.names
+                             if q in query_expression.heading.names]
         columns.update(common_attributes)
         if isinstance(condition, Aggregation):
             condition = condition.make_subquery()
@@ -176,15 +186,17 @@ def make_condition(query_expression, condition, columns):
     except TypeError:
         raise DataJointError('Invalid restriction type %r' % condition)
     else:
-        or_list = [item for item in or_list if item is not False]  # ignore all False conditions
-        if any(item is True for item in or_list):  # if any item is True, the whole thing is True
+        or_list = [item for item in or_list if item is not False]  # ignore False conditions
+        if any(item is True for item in or_list):  # if any item is True, entirely True
             return not negate
-        return template % ('(%s)' % ' OR '.join(or_list)) if or_list else negate  # an empty or list is False
+        return template % ('(%s)' % ' OR '.join(or_list)) if or_list else negate
 
 
 def extract_column_names(sql_expression):
     """
-    extract all presumed column names from an sql expression such as the WHERE clause, for example.
+    extract all presumed column names from an sql expression such as the WHERE clause,
+    for example.
+
     :param sql_expression: a string containing an SQL expression
     :return: set of extracted column names
     This may be MySQL-specific for now.
@@ -206,5 +218,8 @@ def extract_column_names(sql_expression):
     s = re.sub(r"(\b[a-z][a-z_0-9]*)\(", "(", s)
     remaining_tokens = set(re.findall(r"\b[a-z][a-z_0-9]*\b", s))
     # update result removing reserved words
-    result.update(remaining_tokens - {"is", "in", "between", "like", "and", "or", "null", "not"})
+    result.update(remaining_tokens - {"is", "in", "between", "like", "and", "or", "null",
+                                      "not", "interval", "second", "minute", "hour", "day",
+                                      "month", "week", "year"
+                                      })
     return result
