@@ -29,9 +29,7 @@ def ordered_dir(class_):
     """
     attr_list = list()
     for c in reversed(class_.mro()):
-        attr_list.extend(e for e in (
-            c._ordered_class_members if hasattr(c, '_ordered_class_members') else c.__dict__)
-            if e not in attr_list)
+        attr_list.extend(e for e in c.__dict__ if e not in attr_list)
     return attr_list
 
 
@@ -374,9 +372,9 @@ class Schema:
         as ~logs and ~job
         :return: A list of table names from the database schema.
         """
-        return [table_name for (table_name,) in self.connection.query("""
-            SELECT table_name FROM information_schema.tables
-            WHERE table_schema = %s and table_name NOT LIKE '~%%'""", args=(self.database,))]
+        return [t for d, t in (full_t.replace('`', '').split('.')
+                               for full_t in Diagram(self).topological_sort())
+                if d == self.database]
 
 
 class VirtualModule(types.ModuleType):
